@@ -1,5 +1,5 @@
 /*
- * i-scream central monitoring system
+ * i-scream libstatgrab
  * http://www.i-scream.org
  * Copyright (C) 2000-2004 i-scream
  *
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- * $Id: page_stats.c,v 1.6 2004/01/19 16:49:19 tdb Exp $
+ * $Id: page_stats.c,v 1.9 2004/04/06 14:52:56 tdb Exp $
  */
 
 #include <stdio.h>
@@ -28,11 +28,10 @@
 int main(int argc, char **argv){
 
 	extern char *optarg;
-	extern int optind;
 	int c;
 
 	int delay = 1;
-	page_stat_t *page_stats;
+	sg_page_stats *page_stats;
 
 	while ((c = getopt(argc, argv, "d:")) != -1){
 		switch (c){
@@ -43,15 +42,15 @@ int main(int argc, char **argv){
 	}
 
 	/* Initialise statgrab */
-	statgrab_init();
+	sg_init();
 
 	/* Drop setuid/setgid privileges. */
-	if (statgrab_drop_privileges() != 0) {
+	if (sg_drop_privileges() != 0) {
 		perror("Error. Failed to drop privileges");
 		return 1;
 	}
 
-	while( (page_stats = get_page_stats_diff()) != NULL){
+	while( (page_stats = sg_get_page_stats_diff()) != NULL){
 		printf("Pages in : %lld\n", page_stats->pages_pagein);
 		printf("Pages out : %lld\n", page_stats->pages_pageout);
 		sleep(delay);
