@@ -18,7 +18,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
  * 02111-1307 USA
  *
- * $Id: memory_stats.c,v 1.35 2007/06/18 20:56:22 tdb Exp $
+ * $Id: memory_stats.c,v 1.36 2010/02/21 10:04:26 tdb Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -86,9 +86,9 @@ sg_mem_stats *sg_get_mem_stats(){
 	int mib[2];
 	u_long physmem;
 	size_t size;
-	u_int free_count;
-	u_int cache_count;
-	u_int inactive_count;
+	u_long free_count;
+	u_long cache_count;
+	u_long inactive_count;
 	int pagesize;
 #endif
 #if defined(NETBSD)
